Struct plaid::categories::Category[][src]

pub struct Category {
    pub category_id: String,
    pub group: String,
    pub hierarchy: Vec<String>,
}

Fields

category_id: String

An identifying number for the category. category_id is a Plaid-specific identifier and does not necessarily correspond to merchant category codes.

group: String

place for physical transactions or special for other transactions such as bank charges.

hierarchy: Vec<String>

A hierarchical array of the categories to which this category_id belongs.